# Astro3Words

Python package to get easily-readable 3-word addresses of astronomical objects 
with 0.1" precision. Feel free to use in any talks, posters, or outreach!

Installation instructions and a quick-start guide are [here](https://astro-3-words.readthedocs.io/en/latest/#).

## Attribution & contribution

Written by Liza Sazonova, Nnaji Jude. Contributions are welcome, please contact Liza at esazono1@jhu.edu

## Future ideas

* Add a web-app for easy conversion without needing a python install
* Accept a wider range of coordinates

[![GitHub license](https://img.shields.io/github/license/astro-nova/astro-3-words)](https://github.com/astro-nova/astro-3-words/blob/main/LICENSE)
